import { AccessToken } from "@prisma/client";

import { prisma } from "@/lib/prisma";

export async function createAccessToken(
  data: Omit<AccessToken, "id" | "createdAt" | "updatedAt" | "error">,
): Promise<AccessToken> {
  const [accessToken] = await prisma.$transaction([
    prisma.accessToken.create({
      data,
    }),
    prisma.authorization.update({
      where: {
        userId_clientId: {
          userId: data.userId,
          clientId: data.clientId,
        },
      },
      data: {
        lastUsedAt: new Date(),
      },
    }),
  ]);

  return accessToken;
}

export async function getAccessTokenByToken(token: string) {
  const now = new Date();
  return prisma.accessToken.findFirst({
    where: {
      token,
      expiresAt: {
        gt: now,
      },
    },
    include: { user: true },
  });
}
